# Generated by Django 3.2.12 on 2022-05-25 10:08

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("django_secret_sharing", "0001_add_secret_model"),
    ]

    operations = [
        migrations.AddField(
            model_name="secret",
            name="expires_at",
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name="secret",
            name="view_once",
            field=models.BooleanField(default=True),
        ),
        migrations.AlterField(
            model_name="secret",
            name="created_at",
            field=models.DateTimeField(auto_now_add=True),
        ),
    ]
